==> qelectrotech_0.4.orig.tar.gz: qelectrotech-0.4-src/lang/qet_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>QETElementEditor</name>
    <message numerus="yes">
        <location filename="../sources/editor/qetelementeditor.cpp" line="589"/>
        <source>%n partie(s) sélectionnée(s).</source>
        <translation>
            <numerusform>%n partie sélectionnée.</numerusform>
            <numerusform>%n parties sélectionnées.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/editor/qetelementeditor.cpp" line="684"/>
        <source>La vérification de cet élément a généré %n avertissement(s) :</source>
        <comment>message box content</comment>
        <translation>
            <numerusform>La vérification de cet élément a généré %n avertissement :</numerusform>
            <numerusform>La vérification de cet élément a généré %n avertissements :</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <location filename="../sources/qet.cpp" line="238"/>
        <source>%n élément(s)</source>
        <comment>part of a sentence listing the content of a diagram</comment>
        <translation>
            <numerusform>%n élément</numerusform>
            <numerusform>%n éléments</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/qet.cpp" line="261"/>
        <source>%n conducteur(s)</source>
        <comment>part of a sentence listing the content of a diagram</comment>
        <translation>
            <numerusform>%n conducteur</numerusform>
            <numerusform>%n conducteurs</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/qet.cpp" line="283"/>
        <source>%n champ(s) de texte</source>
        <comment>part of a sentence listing the content of a diagram</comment>
        <translation>
            <numerusform>%n champ de texte</numerusform>
            <numerusform>%n champs de texte</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/qet.cpp" line="298"/>
        <source>%n image(s)</source>
        <comment>part of a sentence listing the content of a diagram</comment>
        <translation>
            <numerusform>%n image</numerusform>
            <numerusform>%n image</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/qet.cpp" line="306"/>
        <source>%n forme(s)</source>
        <comment>part of a sentence listing the content of a diagram</comment>
        <translation>
            <numerusform>%n forme</numerusform>
            <numerusform>%n formes</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/titleblock/templatecommands.cpp" line="928"/>
        <source>Couper %n cellule(s)</source>
        <comment>undo caption</comment>
        <translation>
            <numerusform>Couper %n cellule</numerusform>
            <numerusform>Couper %n cellules</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/titleblock/templatecommands.cpp" line="952"/>
        <source>Coller %n cellule(s)</source>
        <comment>undo caption</comment>
        <translation>
            <numerusform>Coller %n cellule</numerusform>
            <numerusform>Coller %n cellules</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/diagramcommands.cpp" line="1236"/>
        <location filename="../sources/diagramcommands.cpp" line="1251"/>
        <source>Délier %n élément(s)</source>
        <translation>
            <numerusform>Délier %n élément</numerusform>
            <numerusform>Délier %n éléments</numerusform>
        </translation>
    </message>
</context>
</TS>

==> qelectrotech_0.5.orig.tar.gz: qelectrotech-0.5-src/lang/qet_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>QETElementEditor</name>
    <message numerus="yes">
        <location filename="../sources/editor/qetelementeditor.cpp" line="634"/>
        <source>%n partie(s) sélectionnée(s).</source>
        <translation>
            <numerusform>%n partie sélectionnée.</numerusform>
            <numerusform>%n parties sélectionnées.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/editor/qetelementeditor.cpp" line="729"/>
        <source> %n erreur(s)</source>
        <comment>errors</comment>
        <translation>
            <numerusform> %n erreur</numerusform>
            <numerusform> %n erreurs</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/editor/qetelementeditor.cpp" line="736"/>
        <source> %n avertissment(s)</source>
        <comment>warnings</comment>
        <translation>
            <numerusform> %n avertissment</numerusform>
            <numerusform> %n avertissments</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <location filename="../sources/qet.cpp" line="238"/>
        <source>%n élément(s)</source>
        <comment>part of a sentence listing the content of a diagram</comment>
        <translation>
            <numerusform>%n élément</numerusform>
            <numerusform>%n éléments</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/qet.cpp" line="261"/>
        <source>%n conducteur(s)</source>
        <comment>part of a sentence listing the content of a diagram</comment>
        <translation>
            <numerusform>%n conducteur</numerusform>
            <numerusform>%n conducteurs</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/qet.cpp" line="283"/>
        <source>%n champ(s) de texte</source>
        <comment>part of a sentence listing the content of a diagram</comment>
        <translation>
            <numerusform>%n champ de texte</numerusform>
            <numerusform>%n champs de texte</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/qet.cpp" line="298"/>
        <source>%n image(s)</source>
        <comment>part of a sentence listing the content of a diagram</comment>
        <translation>
            <numerusform>%n image</numerusform>
            <numerusform>%n image</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/qet.cpp" line="306"/>
        <source>%n forme(s)</source>
        <comment>part of a sentence listing the content of a diagram</comment>
        <translation>
            <numerusform>%n forme</numerusform>
            <numerusform>%n formes</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/titleblock/templatecommands.cpp" line="928"/>
        <source>Couper %n cellule(s)</source>
        <comment>undo caption</comment>
        <translation>
            <numerusform>Couper %n cellule</numerusform>
            <numerusform>Couper %n cellules</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../sources/titleblock/templatecommands.cpp" line="952"/>
        <source>Coller %n cellule(s)</source>
        <comment>undo caption</comment>
        <translation>
            <numerusform>Coller %n cellule</numerusform>
            <numerusform>Coller %n cellules</numerusform>
        </translation>
    </message>
</context>
</TS>
